#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_quartet_manifest
------------

Tests for `quartet_manifest` models module.
"""


from django.urls import reverse
from rest_framework.test import APITestCase




class TestQuartet_manifest(APITestCase):

    def setUp(self):
        pass

    def test_manifest(self):
        url = reverse('quartet-manifest')
        response = self.client.get(url, format='xml')
        print(response.content)

    def tearDown(self):
        pass



from django.conf import settings
from rest_framework.decorators import api_view
from rest_framework.response import Response

@api_view(['GET'])
def get_apps(request):
    '''
    List the installed apps for the UI.
    :return: A list of the installed apps on the system (excluding django
    apps).
    '''
    apps = [setting for setting in settings.INSTALLED_APPS \
            if 'django.' not in setting]
    return Response(apps)




# -*- coding: utf-8 -*-
from django.conf.urls import url

from . import views

app_name = 'quartet_manifest'

urlpatterns = [
    url(r'^quartet-manifest/$', views.get_apps, name='quartet-manifest'),
]



# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Copyright 2018 SerialLab Corp.  All rights reserved.
'''
Contains helper functions that help inspect the local system
with the intent of reporting back settings and capabilities.
'''

from django.conf import settings

def get_asdf():
    '''
    Returns a list of serial-lab specific packages installed on the
    system.
    :return: A list of package names.
    '''
    return settings.INSTALED_APPS



# -*- coding: utf-8 -*-
from __future__ import unicode_literals, absolute_import

from django.conf.urls import url, include

from quartet_manifest.urls import urlpatterns as quartet_manifest_urls

app_name = 'quartet_manifest'

urlpatterns = [
    url(r'^', include(quartet_manifest_urls,
                      )),
]
